@@ -1,7 +1,3 @@
-# FIXME: do we really need to support this class ?
-
-constructors$constructive_options <- new.env()
-
 #' Constructive options for the class `constructive_options`
 #'
 #' These options will be used on objects of class `constructive_options`.
@@ -11,24 +7,20 @@ constructors$constructive_options <- new.env()
 #' * `"next"` : Use the constructor for the next supported class. Call `.class2()`
 #'   on the object to see in which order the methods will be tried.
 #'
-#' @param constructor String. Name of the function used to construct the environment, see Details section.
+#' @param constructor String. Name of the function used to construct the object, see Details section.
 #' @inheritParams opts_atomic
-#' @return An object of class <constructive_options/constructive_options_array>
+#' @return An object of class <constructive_options/constructive_options_constructive_options>
 #' @export
 opts_constructive_options <- function(constructor = c("opts", "next"), ...) {
-  .cstr_combine_errors(
-    constructor <- .cstr_match_constructor(constructor, "constructive_options"),
-    check_dots_empty()
-  )
-  .cstr_options("constructive_options", constructor = constructor)
+  .cstr_options("constructive_options", constructor = constructor[[1]], ...)
 }
 
 #' @export
+#' @method .cstr_construct constructive_options
 .cstr_construct.constructive_options <- function(x, ...) {
-  opts <- .cstr_fetch_opts("constructive_options", ...)
+  opts <- list(...)$opts$constructive_options %||% opts_constructive_options()
   if (is_corrupted_constructive_options(x) || opts$constructor == "next") return(NextMethod())
-  constructor <- constructors$constructive_options[[opts$constructor]]
-  constructor(x, ...)
+  UseMethod(".cstr_construct.constructive_options", structure(NA, class = opts$constructor))
 }
 
 is_corrupted_constructive_options <- function(x) {
@@ -36,7 +28,9 @@ is_corrupted_constructive_options <- function(x) {
   FALSE
 }
 
-constructors$constructive_options$opts <- function(x, ...) {
+#' @export
+#' @method .cstr_construct.constructive_options opts
+.cstr_construct.constructive_options.opts <- function(x, ...) {
   pattern <- "^constructive_options_(.*)$"
   suffix <- sub(pattern, "\\1", grep(pattern, class(x), value = TRUE))
   # FIXME: there should be 1 and only 1, else it's a corrupted object
@@ -44,6 +38,7 @@ constructors$constructive_options$opts <- function(x, ...) {
   fun <- paste0("constructive::opts_", suffix)
   # don't name the constructor arg, and don't provide if it's the default
   constructor_pos <- which("constructor" == rlang::names2(x))
+  x_bkp <- x
   if (length(constructor_pos)) {
     names(x)[[constructor_pos]] <- ""
     if (x[[constructor_pos]] == as.list(eval(parse(text = fun)))$constructor[[2]]) {
@@ -51,7 +46,7 @@ constructors$constructive_options$opts <- function(x, ...) {
     }
   }
   code <- .cstr_apply(x, fun, ...)
-  repair_attributes_constructive_options(x, code, ...)
+  repair_attributes_constructive_options(x_bkp, code, ...)
 }
 
 repair_attributes_constructive_options <- function(x, code, ..., pipe = NULL) {
