@@ -32,7 +32,7 @@ is_corrupted_simpleMessage <- function(x) {
 
 repair_attributes_simpleMessage <- function(x, code, pipe = NULL, ...) {
   .cstr_repair_attributes(
-    x, code, pipe,
+    x, code, pipe = pipe,
     idiomatic_class = c("simpleMessage", "message", "condition"),
     ...
   )
