@@ -6,6 +6,8 @@ all_opts_funs <- NULL
   all_opts_funs <<- mget(all_opts_funs_chr, ns)
   s3_register("roxygen2::roxy_tag_parse", "roxy_tag_enumerateOptFunctions")
   s3_register("roxygen2::roxy_tag_rd", "roxy_tag_enumerateOptFunctions")
+  # Initialize registry for this session
+  globals[["external_pointers"]] <- list()
 }
 
 global_variables <- function() {
