@@ -1,5 +1,5 @@
 test_that("quosure", {
-  expect_pipe_snapshot({
+  expect_snapshot({
     construct(rlang::new_quosure(quote(x), .GlobalEnv))
     construct(rlang::new_quosure(quote(x), .GlobalEnv), opts_quosure("next"))
     construct(rlang::new_quosure(quote(x), .GlobalEnv), opts_quosure("language"))
